<template>
    <div class="full-page bg">
        <div v-loading.fullscreen.lock="markLoading" class="search-container"
            element-loading-background="rgba(255,255,255, 0.5)" element-loading-spinner="el-icon-loading"
            element-loading-text="数据加载中...">
            <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
                <el-row :gutter="20">
                    <el-col :span="5">
                        <el-form-item label="指标名称">
                            <el-input v-model="querys[0].value" placeholder="请输入指标名称" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="指标类型">
                            <dict-select dictCode="sj_zblx" :hasDefaultOption="true" clearable v-model="querys[1].value"
                                style="width: 100%" placeholder="请选择指标类型" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="启用状态">
                            <el-select v-model="querys[2].value" placeholder="请选择启用状态" clearable>
                                <el-option v-for="item in options" :key="item.value" :label="item.label"
                                    :value="item.value">
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button class="btn btn-plus" icon="el-icon-search" type="primary" @click="handleSearch(1)">
                            搜索
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col ref="contentPanel" :span="24" class="table-container" style="padding: 20px">
                <div ref="btnPanel" style="margin-bottom: 10px">
                    <el-button class="btn btn-plus" icon="el-icon-plus" type="primary" @click="handleAdd">
                        {{ this.$t('common.add') }}
                    </el-button>
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table ref="multipleSelection" v-loading="loading" :data="tableData" :max-height="tableMaxHeight"
                        :style="{ width: '100%' }" size="mini" stripe @selection-change="handleSelectionChange">
                        <!-- <el-table-column :selectable="selectHandle" align="center" type="selection"
                            width="55"></el-table-column> -->
                        <el-table-column align="center" type="index" label="序号" width="60"></el-table-column>
                        <el-table-column align="center" label="指标名称" prop="indexName" min-width="120"
                            show-overflow-tooltip>
                            <template v-slot="{ row }">
                                <el-input v-if="row.type === 'edit'" v-model="row.indexName"
                                    placeholder="请输入指标名称"></el-input>
                                <div v-else>{{ row.indexName }}</div>
                            </template>
                        </el-table-column>
                        <el-table-column prop="indexType" width="150" show-overflow-tooltip label="指标类型" align="center">
                            <template v-slot="{ row }">
                                <dict-select v-if="row.type === 'edit'" dictCode="sj_zblx" :hasDefaultOption="true"
                                    clearable v-model="row.indexType" style="width: 100%" placeholder="请选择指标类型" />
                                <div v-else>{{ getDictName('sj_zblx', row.indexType) }}</div>
                            </template>
                        </el-table-column>
                        <el-table-column align="center" label="单位" prop="indexUnit" width="150" show-overflow-tooltip>
                            <template v-slot="{ row }">
                                <el-input v-if="row.type === 'edit'" v-model="row.indexUnit"
                                    placeholder="请输入指标单位"></el-input>
                                <div v-else>{{ row.indexUnit }}</div>
                            </template>
                        </el-table-column>
                        <el-table-column align="center" label="排序号" prop="sn" width="100" show-overflow-tooltip>
                            <template v-slot="{ row }">
                                <el-input v-if="row.type === 'edit'" v-model="row.sn" placeholder="请输入排序号"></el-input>
                                <div v-else>{{ row.sn }}</div>
                            </template>
                        </el-table-column>
                        <el-table-column align="center" label="启用状态" prop="isUse" width="100" show-overflow-tooltip>
                            <template v-slot="{ row }">
                                <el-switch v-model="row.isUse" active-color="#13ce66" inactive-color="#ff4949"
                                    @change="switchChange(row)">
                                </el-switch>
                            </template>
                        </el-table-column>
                        <el-table-column align="center" fixed="right" label="操作" show-overflow-tooltip width="160">
                            <template v-slot="{ row, $index }">
                                <template v-if="row.type === 'edit'">
                                    <el-link :underline="false" class="cloumn-btn" type="primary"
                                        @click="handleDbClick(row)">
                                        保存
                                    </el-link>
                                    <!-- 1px solid #dcdfe6 -->
                                    <el-link :underline="false" class="cancel-btn" @click="handleCancel(row)">
                                        取消
                                    </el-link>
                                </template>

                                <el-link v-else :underline="false" class="cloumn-btn" type="primary"
                                    @click="handleEdit(row, $index)">
                                    编辑
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" :pageResult="queryParam.pageBean" style="margin-top: 10px"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import projectsAPI from '@/api/municipalReform/index.js'
import api from '@/api/ReformSituation/municipal'
import utils from '@/utils'

export default {
    name: 'IndexManagement',
    components: {
        pagination
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            searchForm: {},
            loading: false,
            tableData: [],
            multipleSelection: [],
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'index_Name_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'index_type_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'is_use_',
                    relation: 'AND',
                    value: '',
                },
            ],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0
                }
            },
            options: [
                { label: '启用', value: 1 },
                { label: '禁用', value: 0 }
            ]
        }
    },
    created() {
        this.getData()
    },
    mounted() { },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        selectHandle(row) {
            if (row.status != 1) {
                return true
            }
        },

        // 字段必填校验
        requiredCheck(data) {
            const { indexName, indexType, indexUnit, sn } = data
            if (!indexName) {
                this.$message.error('指标名称不能为空')
                return false
            } else if (!indexType) {
                this.$message.error('指标类型不能为空')
                return false
            } else if (!indexUnit) {
                this.$message.error('指标单位不能为空')
                return false
            } else if (!sn) {
                this.$message.error('排序号不能为空')
                return false
            } else {
                return true
            }
        },

        // 添加
        handleAdd() {
            this.tableData.unshift({
                indexName: '',
                indexType: 1,
                indexUnit: '',
                sn: '',
                isUse: true,
                type: 'edit'
            })
        },

        // 
        handleEdit(row, index) {
            row.type = 'edit'
        },
        // 启用或禁用指标
        switchChange(row) {
            if (row.id) {
                this.loading = true
                let data = JSON.parse(JSON.stringify(row))
                data.isUse = data.isUse ? 1 : 0
                api.updateIndex(data).then(res => {
                    if (res.state) {
                        let msg = data.isUse ? '指标启用成功！' : '指标禁用成功！'
                        this.$message.success(msg)
                        this.getData()
                    }
                })
            }
        },

        // 取消
        handleCancel(row) {
            if (row.id) {
                row.type = 'detail'
            } else {
                this.tableData.shift()
            }
        },

        //保存
        handleDbClick(row) {
            let data = JSON.parse(JSON.stringify(row))
            data.isUse = data.isUse ? 1 : 0
            let flag = this.requiredCheck(data)
            if (flag) {
                this.loading = true
                let apiName = row.id ? 'updateIndex' : 'addIndex'
                api[apiName](data).then(res => {
                    if (res.state) {
                        let msg = row.id ? '指标修改保存成功！' : '新增指标成功！'
                        this.$message.success(msg)
                        this.getData()
                    }
                })
            }
        },

        handleSearch(page) {
            this.queryParam.querys = []
            this.querys.forEach(item => {
                if (item.value !== undefined) {
                    this.queryParam.querys.push(item)
                }
            })
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.getData()
        },
        //获取数据
        getData() {
            this.loading = true
            this.tableData = []
            this.queryParam.querys = this.querys
            api.getIndexTable(this.queryParam).then(res => {
                if (res.rows) {
                    let arr = res.rows.map(item => {
                        item.isUse = item.isUse > 0 ? true : false
                        item.type = 'detail'
                        return item
                    })
                    this.tableData = arr.sort((a, b) => a.sn - b.sn)
                    this.queryParam.pageBean.page = res.page
                    this.queryParam.pageBean.total = res.total
                    // this.$set(this.tableData)
                    this.loading = false
                }
            })
        },

        //表格选中
        handleSelectionChange(val) {
            this.multipleSelection = []
            this.$refs.multipleSelection.selection.forEach(item => {
                this.multipleSelection.push(item.id)
            })
        },
        //展示数量
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.handleSearch(1)
        },
        //表格页数
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.handleSearch(val)
        }
    }
}
</script>

<style lang="scss" scoped>
.cancel-btn {
    padding: 3px 10px;
    border-radius: 5px;
    border: 1px solid #dcdfe6;

    &:hover {
        background: #ecf5ff;
        border: 1px solid #c6e2ff;
    }
}

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(2) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}
</style>